@@ -35,14 +35,14 @@ _pkg_config = {
     'py_conf_inc_dir':    '/usr/include/python3.6m',
     'py_inc_dir':         '/usr/include/python3.6m',
     'py_lib_dir':         '/usr/lib/python3.6/config',
-    'py_version':         0x030600,
+    'py_version':         0x030601,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro',
+    'sip_config_args':    'CFLAGS=-march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro',
     'sip_inc_dir':        '/usr/include/python3.6m',
     'sip_mod_dir':        '/usr/lib/python3.6/site-packages',
-    'sip_version':        0x041301,
-    'sip_version_str':    '4.19.1',
+    'sip_version':        0x041302,
+    'sip_version_str':    '4.19.2',
     'universal':          ''
 }
 
@@ -50,7 +50,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=armv5te -O2 -pipe -fstack-protector --param=ssp-buffer-size=4',
+    'CFLAGS':                   '-march=armv5te -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
